==> one_target_mobile_sdk-0.0.7.tar.gz: example/lib/screens/tracking/advancedTracking/ticket_detail_screen.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';
import 'package:one_target_mobile_sdk_example/screens/tracking/advancedTracking/booking_success_screen.dart';

class TicketDetailScreen extends StatefulWidget {
  const TicketDetailScreen({Key? key}) : super(key: key);

  @override
  State<TicketDetailScreen> createState() => _TicketDetailScreenState();
}

class _TicketDetailScreenState extends State<TicketDetailScreen> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          children: [
            const SizedBox(height: 16.0),
            const SizedBox(height: 16.0),
            Align(
              alignment: Alignment.center,
              child: Utils.getText(
                "Hồ Chí Minh - Hà Nội",
                18,
                FontWeight.w500,
                Colors.black,
              ),
            ),
            const SizedBox(height: 16.0),
            Expanded(
              child: Container(
                decoration: BoxDecoration(
                  border: Border.all(
                    width: 1.0,
                    color: Colors.grey,
                  ),
                  borderRadius: const BorderRadius.all(Radius.circular(0)),
                ),
                child: ListView(
                  padding: EdgeInsets.zero,
                  physics: const BouncingScrollPhysics(),
                  children: [
                    Utils.getTitle("Chủ nhật, 3 tháng 8 2022"),
                  ],
                ),
              ),
            ),
            const SizedBox(height: 16.0),
            Utils.getButton(
              "Tiếp theo",
              16.0,
              Colors.white,
              Colors.deepPurple,
              null,
              () {
                Get.to(() => const BookingDetailScreen());
              },
            ),
            const SizedBox(height: 16.0),
          ],
        ),
      ),
    );
  }
}

==> one_target_mobile_sdk-0.0.11.tar.gz: example/lib/screens/tracking/advancedTracking/ticket_detail_screen.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';
import 'package:one_target_mobile_sdk_example/screens/tracking/advancedTracking/booking_success_screen.dart';

class TicketDetailScreen extends StatefulWidget {
  const TicketDetailScreen({Key? key}) : super(key: key);

  @override
  State<TicketDetailScreen> createState() => _TicketDetailScreenState();
}

class _TicketDetailScreenState extends State<TicketDetailScreen> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          children: [
            const SizedBox(height: 16.0),
            const SizedBox(height: 16.0),
            Align(
              alignment: Alignment.center,
              child: Utils.getText(
                "Hồ Chí Minh - Hà Nội",
                18,
                FontWeight.w500,
                Colors.black,
              ),
            ),
            const SizedBox(height: 16.0),
            Expanded(
              child: Container(
                decoration: BoxDecoration(
                  border: Border.all(
                    width: 1.0,
                    color: Colors.grey,
                  ),
                  borderRadius: const BorderRadius.all(Radius.circular(0)),
                ),
                child: ListView(
                  padding: EdgeInsets.zero,
                  physics: const BouncingScrollPhysics(),
                  children: [
                    Utils.getTitle("Chủ nhật, 3 tháng 8 2022"),
                  ],
                ),
              ),
            ),
            const SizedBox(height: 16.0),
            Utils.getButton(
              "Tiếp theo",
              16.0,
              Colors.white,
              Colors.deepPurple,
              null,
              () {
                Get.to(() => const BookingSuccessScreen());
              },
            ),
            const SizedBox(height: 16.0),
          ],
        ),
      ),
    );
  }
}
